/*
 * File contenente l'interfaccia del modulo Manipolazione/Stampa
 */

#include <iostream>
using namespace std ;

/* Inizio interfaccia del modulo Manipolazione/Stampa */

/* Inizializzazione di una sequenza. 
 * Da invocarsi prima di utilizzare la sequenza. 
 * Parametri: s = Descrittore della sequenza 
 *            t = Tipo della chiave, di tipo tipo_chiave_t
 */
void inizializza(desc_sequenza &s, const tipo_chiave_t t) ;

/* Distruzione di una sequenza.
 * Libera la memoria utilizzata dalla sequenza.
 * Parametri:  s = Descrittore della sequenza da distruggere
 */
void distruggi(desc_sequenza &s) ;

/* Inserimento di un elemento nella sequenza.
 * E' possibile inserire l'elemento in testa, in coda o in ordine
 * crescente, in base al valore del parametro modo.  
 * Attenzione: nella
 * sequenza viene memorizzato l'indirizzo dell'elemento, per cui chi
 * invoca la funzione inserisci deve assicurarsi che tale elemento non
 * sia poi deallocato. Saranno le funzioni elimina e distruggi ad
 * occuparsi della deallocazione dell'elemento.
 *
 * Parametri: s Sequenza in cui inserire l'elemento
 * Parametri: el Elemento (pre-inizializzato) da inserire
 * Parametri: modo modalit di inserimento (vedi ins_modo)
 */
void inserisci(desc_sequenza &s, elem *el, ins_modo modo) ;

/* Cerca l'elemento con la chiave richiesta nella sequenza.
 *
 * Parametri: s Sequenza in cui cercare l'elemento
 * Parametri:c Chiave da cercare. La chiave  rappresentata mediante una 
 *              stringa, che, nel caso di chiave numerica,  uguale alla 
 *              rappresentazione in base 10 della chiave da cercare.
 * Ritorna l'indice dell'elemento contenente la chiave cercata in caso di 
 *        successo, o -1 in caso di fallimento.
 */
int cerca(const desc_sequenza &s, const char c[]) ;

/* Elimina elemento dalla sequenza per valore. 
 * Cerca l'elemento con chiave uguale a quella passata in ingresso e, se
 * lo trova, lo elimina.
 *
 * Parametri: s Sequenza in cui cercare ed eliminare l'elemento
 * Parametri: c Chiave dell'elemento da cercare.
 * Ritorna vero in caso di successo dell'eliminazione
 *
 */

bool elimina(desc_sequenza &s, const char c[]) ;

/* Stampa del contenuto di un elemento.
 * Parametri: el Elemento da stampare
 * Parametri: os Output stream su cui effettuare l'uscita
 */
void stampa_elem(const elem &el, ostream &os) ;

/* Stampa del contenuto della sequenza.
 * Parametri: s Sequenza da stampare
 */
void stampa(const desc_sequenza &s) ;

// Fine interfaccia del modulo Manipolazione/Stampa
